pub struct PasswordManagerTokenHandler {
inner: Arc<RwLock<PasswordManagerTokenHandlerInner>>,
}Expand description
Token handler for Bitwarden authentication.
Fields
inner: Arc<RwLock<PasswordManagerTokenHandlerInner>>Trait Implementations
Sourceimpl Clone for PasswordManagerTokenHandler
impl Clone for PasswordManagerTokenHandler
Sourcefn clone(&self) -> PasswordManagerTokenHandler
fn clone(&self) -> PasswordManagerTokenHandler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PasswordManagerTokenHandler
impl Default for PasswordManagerTokenHandler
Sourcefn default() -> PasswordManagerTokenHandler
fn default() -> PasswordManagerTokenHandler
Returns the “default value” for a type. Read more
Sourceimpl TokenHandler for PasswordManagerTokenHandler
impl TokenHandler for PasswordManagerTokenHandler
Sourcefn initialize_middleware(
&self,
login_method: Arc<RwLock<Option<Arc<LoginMethod>>>>,
identity_config: Configuration,
_key_store: KeyStore<KeyIds>,
) -> Arc<dyn Middleware>
fn initialize_middleware( &self, login_method: Arc<RwLock<Option<Arc<LoginMethod>>>>, identity_config: Configuration, _key_store: KeyStore<KeyIds>, ) -> Arc<dyn Middleware>
Initialize middleware that handles token attachment and renewal.
This middleware should look for the presence of the [bitwarden_api_base::AuthRequired]
extension to decide when to attach tokens. It’s then free to attach tokens as it sees fit,
including pausing and retrying requests to renew tokens.
Sourcefn set_tokens(
&self,
access_token: String,
refresh_token: Option<String>,
expires_in: u64,
)
fn set_tokens( &self, access_token: String, refresh_token: Option<String>, expires_in: u64, )
This method is available only as a backwards compatibility measure until all the
auth-related code is moved out of core. Once that is done, setting tokens should be always
done either during renewal (as part of the middleware) or during registration/login, in
which case it would be up to the auth crate to internally set those tokens when initializing
the client.